summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorQt Continuous Integration System <qt-info@nokia.com>2010-09-21 09:22:33 (GMT)
committerQt Continuous Integration System <qt-info@nokia.com>2010-09-21 09:22:33 (GMT)
commitb9af296af3d4792d591afd833301ce56bcbc7b55 (patch)
tree80b8f2463fadf290afa3206dd1cf6cebe35a906f
parentcd2fd21578a80bc5ac121c0419ee00b1799d0a60 (diff)
parentdbe7af4ad982186d26f6e3dbf5dad8e97b318443 (diff)
downloadQt-b9af296af3d4792d591afd833301ce56bcbc7b55.zip
Qt-b9af296af3d4792d591afd833301ce56bcbc7b55.tar.gz
Qt-b9af296af3d4792d591afd833301ce56bcbc7b55.tar.bz2
Merge branch 'master' of scm.dev.nokia.troll.no:qt/oslo-staging-1 into master-integration
* 'master' of scm.dev.nokia.troll.no:qt/oslo-staging-1: fix project name duplicates in generated projects.sln Doc: document QMAKE_PROJECT_NAME qmake: introduction of QMAKE_PROJECT_NAME
-rw-r--r--doc/src/development/qmake-manual.qdoc18
-rw-r--r--examples/draganddrop/puzzle/puzzle.pro2
-rw-r--r--examples/graphicsview/flowlayout/flowlayout.pro6
-rw-r--r--examples/script/calculator/calculator.pro1
-rw-r--r--examples/tools/echoplugin/echowindow/echowindow.pro1
-rw-r--r--qmake/generators/win32/msvc_vcproj.cpp6
-rw-r--r--qmake/generators/win32/winmakefile.cpp5
7 files changed, 27 insertions, 12 deletions
diff --git a/doc/src/development/qmake-manual.qdoc b/doc/src/development/qmake-manual.qdoc
index b6b48bc..d6dc7d6 100644
--- a/doc/src/development/qmake-manual.qdoc
+++ b/doc/src/development/qmake-manual.qdoc
@@ -2665,6 +2665,13 @@
value of this variable is typically handled by \c qmake or
\l{#QMAKESPEC}{qmake.conf} and rarely needs to be modified.
+ \section1 QMAKE_LN_SHLIB
+
+ This variable contains the command to execute when creating a link
+ to a shared library. The
+ value of this variable is typically handled by \c qmake or
+ \l{#QMAKESPEC}{qmake.conf} and rarely needs to be modified.
+
\section1 QMAKE_POST_LINK
This variable contains the command to execute after linking the TARGET
@@ -2679,12 +2686,13 @@
executed, additionally some backends will not support this - mostly only
Makefile backends.
- \section1 QMAKE_LN_SHLIB
+ \section1 QMAKE_PROJECT_NAME
- This variable contains the command to execute when creating a link
- to a shared library. The
- value of this variable is typically handled by \c qmake or
- \l{#QMAKESPEC}{qmake.conf} and rarely needs to be modified.
+ \e {This is used for Visual Studio project files only.}
+
+ This variable determines the name of the project when generating project
+ files for IDEs. The default value is the target name. The value of this
+ variable is typically handled by \c qmake and rarely needs to be modified.
\section1 QMAKE_MAC_SDK
diff --git a/examples/draganddrop/puzzle/puzzle.pro b/examples/draganddrop/puzzle/puzzle.pro
index 31786c7..ec88f7a 100644
--- a/examples/draganddrop/puzzle/puzzle.pro
+++ b/examples/draganddrop/puzzle/puzzle.pro
@@ -7,6 +7,8 @@ SOURCES = main.cpp \
pieceslist.cpp \
puzzlewidget.cpp
+QMAKE_PROJECT_NAME = dndpuzzle
+
# install
target.path = $$[QT_INSTALL_EXAMPLES]/draganddrop/puzzle
sources.files = $$SOURCES $$HEADERS $$RESOURCES *.pro *.jpg
diff --git a/examples/graphicsview/flowlayout/flowlayout.pro b/examples/graphicsview/flowlayout/flowlayout.pro
index c029d6c..ce35367 100644
--- a/examples/graphicsview/flowlayout/flowlayout.pro
+++ b/examples/graphicsview/flowlayout/flowlayout.pro
@@ -1,12 +1,10 @@
-######################################################################
-# Automatically generated by qmake (2.01a) ma 30. mar 12:46:15 2009
-######################################################################
-
TEMPLATE = app
TARGET =
DEPENDPATH += .
INCLUDEPATH += .
+QMAKE_PROJECT_NAME = flowlayout_graphicsview
+
# Input
HEADERS += flowlayout.h window.h
SOURCES += flowlayout.cpp main.cpp window.cpp
diff --git a/examples/script/calculator/calculator.pro b/examples/script/calculator/calculator.pro
index 6385d7e..f328fc3 100644
--- a/examples/script/calculator/calculator.pro
+++ b/examples/script/calculator/calculator.pro
@@ -2,6 +2,7 @@ QT += script
CONFIG += uitools
RESOURCES += calculator.qrc
SOURCES += main.cpp
+QMAKE_PROJECT_NAME = scripted_calculator
contains(QT_CONFIG, scripttools): QT += scripttools
diff --git a/examples/tools/echoplugin/echowindow/echowindow.pro b/examples/tools/echoplugin/echowindow/echowindow.pro
index bdf8c41..c2abc6a 100644
--- a/examples/tools/echoplugin/echowindow/echowindow.pro
+++ b/examples/tools/echoplugin/echowindow/echowindow.pro
@@ -4,6 +4,7 @@ SOURCES = echowindow.cpp \
main.cpp
TARGET = echoplugin
+QMAKE_PROJECT_NAME = echopluginwindow
win32 {
debug:DESTDIR = ../debug/
release:DESTDIR = ../release/
diff --git a/qmake/generators/win32/winmakefile.cpp b/qmake/generators/win32/winmakefile.cpp
index ecb20c7..58f21cb 100644
--- a/qmake/generators/win32/winmakefile.cpp
+++ b/qmake/generators/win32/winmakefile.cpp
@@ -290,6 +290,11 @@ void Win32MakefileGenerator::processVars()
}
project->values("QMAKE_ORIG_TARGET") = project->values("TARGET");
+ if (project->isEmpty("QMAKE_PROJECT_NAME"))
+ project->values("QMAKE_PROJECT_NAME") = project->values("QMAKE_ORIG_TARGET");
+ else if (project->first("TEMPLATE").startsWith("vc"))
+ project->values("MAKEFILE") = project->values("QMAKE_PROJECT_NAME");
+
if (!project->values("QMAKE_INCDIR").isEmpty())
project->values("INCLUDEPATH") += project->values("QMAKE_INCDIR");
diff --git a/qmake/generators/win32/msvc_vcproj.cpp b/qmake/generators/win32/msvc_vcproj.cpp
index f32ba7e..3c42f14 100644
--- a/qmake/generators/win32/msvc_vcproj.cpp
+++ b/qmake/generators/win32/msvc_vcproj.cpp
@@ -280,7 +280,7 @@ bool VcprojGenerator::writeProjectMakefile()
mergedProjects.at(0)->vcProject.Name ==
mergedProjects.at(1)->vcProject.Name)
mergedProjects.at(0)->writePrlFile();
- mergedProject.Name = unescapeFilePath(project->first("QMAKE_ORIG_TARGET"));
+ mergedProject.Name = project->first("QMAKE_PROJECT_NAME");
mergedProject.Version = mergedProjects.at(0)->vcProject.Version;
mergedProject.ProjectGUID = project->isEmpty("QMAKE_UUID") ? getProjectUUID().toString().toUpper() : project->first("QMAKE_UUID");
mergedProject.Keyword = project->first("VCPROJ_KEYWORD");
@@ -468,8 +468,8 @@ void VcprojGenerator::writeSubDirs(QTextStream &t)
}
}
- // We assume project filename is [QMAKE_ORIG_TARGET].vcproj
- QString vcproj = unescapeFilePath(tmp_vcproj.project->first("QMAKE_ORIG_TARGET") + project->first("VCPROJ_EXTENSION"));
+ // We assume project filename is [QMAKE_PROJECT_NAME].vcproj
+ QString vcproj = unescapeFilePath(tmp_vcproj.project->first("QMAKE_PROJECT_NAME") + project->first("VCPROJ_EXTENSION"));
QString vcprojDir = qmake_getpwd();
// If file doesn't exsist, then maybe the users configuration